example

package
v0.0.0-...-0ba2d5d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 24, 2022 License: BSD-3-Clause Imports: 5 Imported by: 0

Documentation

Overview

A sample example to interact with the moderator package

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewExample

func NewExample()

Initialize the moderator client and create a simple HTTP endpoint

Types

type Request

type Request struct {
	Text string `json:"text"`
}

HTTP request

type Server

type Server struct {
	// contains filtered or unexported fields
}

Struct to hold the client

func (*Server) AnalyzeText

func (s *Server) AnalyzeText(w http.ResponseWriter, r *http.Request)

Parse post request and analyze text

Jump to