Documentation
¶
Overview ¶
A sample example to interact with the moderator package
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewExample ¶
func NewExample()
Initialize the moderator client and create a simple HTTP endpoint
Types ¶
type Server ¶
type Server struct {
// contains filtered or unexported fields
}
Struct to hold the client
func (*Server) AnalyzeText ¶
func (s *Server) AnalyzeText(w http.ResponseWriter, r *http.Request)
Parse post request and analyze text
Click to show internal directories.
Click to hide internal directories.